aboutsummaryrefslogtreecommitdiffstats
path: root/apps/files_external/tests/env/start-webdav-apache.sh
diff options
context:
space:
mode:
Diffstat (limited to 'apps/files_external/tests/env/start-webdav-apache.sh')
-rwxr-xr-xapps/files_external/tests/env/start-webdav-apache.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/apps/files_external/tests/env/start-webdav-apache.sh b/apps/files_external/tests/env/start-webdav-apache.sh
index 48acb8572d6..a5464c9cfab 100755
--- a/apps/files_external/tests/env/start-webdav-apache.sh
+++ b/apps/files_external/tests/env/start-webdav-apache.sh
@@ -6,7 +6,7 @@
# against. It will also change the files_external config to use the docker
# container as testing environment. This is reverted in the stop step.
#
# If the environment variable RUN_DOCKER_MYSQL is set the ownCloud will
# be set up using MySQL instead of SQLite.
#
# Set environment variable DEBUG to print config file
@@ -74,7 +74,7 @@ return array(
DELIM
-echo "ownCloud container: $container"
+echo "Nextcloud container: $container"
# put container IDs into a file to drop them after the test run (keep in mind that multiple tests run in parallel on the same host)
echo $container >> $thisFolder/dockerContainerWebdav.$EXECUTOR_NUMBER.webdav
@@ -6,7 +6,7 @@
# container as testing environment. This is reverted in the stop step.
#
-# If the environment variable RUN_DOCKER_MYSQL is set the ownCloud will
+# If the environment variable RUN_DOCKER_MYSQL is set the Nextcloud will
# be set up using MySQL instead of SQLite.
#